==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/PivotTableStyle.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class PivotTableStyle (SpireObject) :
    """

    """

    def SetConverter(self ,converter:'SpireObject'):
        """

        """
        intPtrconverter:c_void_p = converter.Ptr

        GetDllLibXls().PivotTableStyle_SetConverter.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PivotTableStyle_SetConverter(self.Ptr, intPtrconverter)

    @property
    def IsDefaultStyle(self)->bool:
        """

        """
        GetDllLibXls().PivotTableStyle_get_IsDefaultStyle.argtypes=[c_void_p]
        GetDllLibXls().PivotTableStyle_get_IsDefaultStyle.restype=c_bool
        ret = GetDllLibXls().PivotTableStyle_get_IsDefaultStyle(self.Ptr)
        return ret

    @IsDefaultStyle.setter
    def IsDefaultStyle(self, value:bool):
        GetDllLibXls().PivotTableStyle_set_IsDefaultStyle.argtypes=[c_void_p, c_bool]
        GetDllLibXls().PivotTableStyle_set_IsDefaultStyle(self.Ptr, value)

    @property

    def Name(self)->str:
        """

        """
        GetDllLibXls().PivotTableStyle_get_Name.argtypes=[c_void_p]
        GetDllLibXls().PivotTableStyle_get_Name.restype=c_void_p
        ret = PtrToStr(GetDllLibXls().PivotTableStyle_get_Name(self.Ptr))
        return ret


#    @property
#
#    def Styles(self)->'Dictionary2':
#        """
#
#        """
#        GetDllLibXls().PivotTableStyle_get_Styles.argtypes=[c_void_p]
#        GetDllLibXls().PivotTableStyle_get_Styles.restype=c_void_p
#        intPtr = GetDllLibXls().PivotTableStyle_get_Styles(self.Ptr)
#        ret = None if intPtr==None else Dictionary2(intPtr)
#        return ret
#

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/PivotTableStyle.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class PivotTableStyle (SpireObject) :
    """

    """

    def SetConverter(self ,converter:'SpireObject'):
        """

        """
        intPtrconverter:c_void_p = converter.Ptr

        GetDllLibXls().PivotTableStyle_SetConverter.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().PivotTableStyle_SetConverter, self.Ptr, intPtrconverter)

    @property
    def IsDefaultStyle(self)->bool:
        """

        """
        GetDllLibXls().PivotTableStyle_get_IsDefaultStyle.argtypes=[c_void_p]
        GetDllLibXls().PivotTableStyle_get_IsDefaultStyle.restype=c_bool
        ret = CallCFunction(GetDllLibXls().PivotTableStyle_get_IsDefaultStyle, self.Ptr)
        return ret

    @IsDefaultStyle.setter
    def IsDefaultStyle(self, value:bool):
        GetDllLibXls().PivotTableStyle_set_IsDefaultStyle.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibXls().PivotTableStyle_set_IsDefaultStyle, self.Ptr, value)

    @property

    def Name(self)->str:
        """

        """
        GetDllLibXls().PivotTableStyle_get_Name.argtypes=[c_void_p]
        GetDllLibXls().PivotTableStyle_get_Name.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibXls().PivotTableStyle_get_Name, self.Ptr))
        return ret


#    @property
#
#    def Styles(self)->'Dictionary2':
#        """
#
#        """
#        GetDllLibXls().PivotTableStyle_get_Styles.argtypes=[c_void_p]
#        GetDllLibXls().PivotTableStyle_get_Styles.restype=c_void_p
#        intPtr = CallCFunction(GetDllLibXls().PivotTableStyle_get_Styles, self.Ptr)
#        ret = None if intPtr==None else Dictionary2(intPtr)
#        return ret
#
